"use strict";

/* Validation du nom */
function nomValide() {
	let nom = document.getElementById("input-nom");
	if (nom.value === "") {
		document.querySelector("#nom .erreur").textContent = "Vous devez indiquer un nom.";
		nom.classList.add("invalide");
		return false;
	}
	return true;
}


/* Validation de l'âge */
function ageValide() {
	let age = document.getElementById("input-age");
	if (age.value < 0) {
		document.querySelector("#age .erreur").textContent = "Votre âge doit être positif.";
		age.classList.add("invalide");
		return false;
	}
	return true;
}

/* Validation des moteurs de recherche */
function moteursValide() {
	/* on vérifie que le panneau «moteurs» est affiché */
	if (document.querySelector("#rech input[type=radio]:checked").value === "non") {
		/* l'internaute ne fait pas de recherches, donc
		 * on ignore les cases cochées */
		return true;
	}
	/* le panneau est affiché : on compte les cases cochées */
	let moteurs = document.querySelectorAll("#moteurs input[type=checkbox]:checked");
	if (moteurs.length > 2) {
		document.querySelector("#moteurs .erreur").textContent = "Vous devez sélectionner au plus 2 moteurs.";
		return false;
	}
	return true;
}

/* Listener de validation */
document.getElementById("formulaire").addEventListener("submit", function (e) {
	/* Le formulaire en cours de soumission */
	let theForm = e.currentTarget;

	/* Remise à zéro des champs invalides */
	/* J'ai laissé l'ancienne version qui n'utilise pas querySelectorAll :
	 * noter que ça oblige à itérer en partant de la fin ! (voir cours) */
	let inv = theForm.getElementsByClassName("invalide");
	for (let i = inv.length - 1; i >= 0; i--) {
		inv[i].classList.remove("invalide");
	}

	/* Vidage des erreurs */
	let err = theForm.getElementsByClassName("erreur");
	for (let i = 0; i < err.length; i++) {
		err[i].textContent = "";
	}

	/* Validation : par défaut, le formulaire est valide,
	 * et on effectue les validations une par une (on veut
	 * qu'elles soient toutes exécutées, même si le premier
	 * champ est déjà invalide). Attention à l'ordre des
	 * arguments du «&&» ! */
	let valide = true;
	valide = nomValide() && valide;
	valide = ageValide() && valide;
	valide = moteursValide() && valide;

	/* Y a-t-il eu des erreurs ? */
	if (!valide) {
		e.preventDefault();
	}
});

/* Cachage du choix des moteurs */
let moteurs = document.getElementById("moteurs");

function toggleMoteurs () {
	moteurs.classList.toggle("cachee");
}

/* On récupère les inputs du fieldset #rech grâce à
 * l'attribut «elements» de l'interface HTMLFieldSetElement
 * (également présent dans HTMLFormElement)
 */
let boutons = document.getElementById("rech").elements;
let valInitiale = "oui";
for (let i = 0; i < boutons.length; i++) {
	boutons[i].addEventListener("click", toggleMoteurs);
	if (boutons[i].checked) {
		valInitiale = boutons[i].value;
	}
}
if (valInitiale === "non") {
	toggleMoteurs();
}

/* Retour à zéro */
document.getElementById("raz").addEventListener("click", function (e) {
	document.getElementById("input-nom").value = "";
	document.getElementById("input-age").value = "";
	let rech = document.querySelector("#rech input[value=\"oui\"]");
	if (!rech.checked) {
		rech.checked = true;
		toggleMoteurs();
	}
	let checkboxes = document.getElementById("moteurs").elements;
	for (let i = 0; i < checkboxes.length; i++) {
		checkboxes[i].checked = false;
	}
});

